{SLS Block 1C constants. Steven S. Pietrobon 21 Dec 1997.
 Revised  7 Feb 1998, 15 Sep 2012, 20 July 2013
 14 Sep 2013 Added second stage optimisation
 19 Oct 2013}

const Name = 'SLS';

  {Stage 1 constants}
  S1_Name =   'RSRMV';
  S1_Mp   =  633233.1; {kg, propellant mass}
  S1_Ms   =  100543.3; {kg, burnout mass}
  S1_N    =         2; {no. of boosters}
  S1_D    =    5.1562; {m,  aft-skirt diameter}
  S1_De   =    3.8748; {m,  nozzle average diameter}
  S1_V    =    2622.3; {m/s, vacuum exhaust speed}
  S1_Ta   =     131.9; {s,  action time}
 
  {Stage 2 constants}
  S2_Name =   'Core';
  S2_Mp1   =  964825; {kg, mainstage propellant mass used, 983388 kg total -
                           7439 kg startup - 8210 kg reserve - 1678 kg residual
                           - 1236 kg cutoff}
  S2_Mp2   =    1236; {kg, cut off propellant mass used}
  S2_Ms    =  125463; {kg, dry mass 115575 + 8210 kg reserve + 1678 kg residual}
  S2_D     =  8.4074; {m,  stage diameter}
  S2_A     =   0.235; {m^2, LOX feed line, sqr(D)*(1+pi/4)/2}
  S2_Ts    =    0.76; {s, separation time after MECO}
  S2_Tj    =     330; {s,  time to LAS jettison}

  {Stage 2 engine constants}
  S2_Eng_Name = 'RS-25D';
  S2_N     =       4; {no. of engines}
  S2_F     = 2090664; {N,   vacuum thrust}
  S2_Fs    = 1668083; {N,   sea level thrust}
  S2_V     =  4436.5; {m/s, vacuum exhaust speed}
  S2_I     =    0.01; {thrust incremental ratio}
  S2_R     =    1.09; {thrust ratio}

  {Stage 3 constants}
  S3_Name  = 'Upper Stage';
  {Constants below updated with simulation}
  S3_Mi    =    5944; {kg, interstage mass}
  S3_Mp1   =     771; {kg, startup propellant mass}
  S3_Mp2   =  125292; {kg, mainstage propellant mass used, 128177 kg total -
                           771 kg startup - 2114 kg reserve}
  S3_Ms    =   21221; {kg, cutoff mass, 102 kg RCS propellant + 19005 kg dry +
                           2114 kg reserve}
  S3_Mup   =     115; {kg, total ullage motor propellant}
  S3_Mus   =     117; {kg, total ullage motor empty}
  S3_Fu    =   65032; {N,  total ullage motor vacuum thrust}
  SC_M     =  102762; {kg, Spacecraft mass}

  S3_N     =       2; {no. of engines}
  S3_T1    =     3.4; {s,  time to engine start}
  S3_Ts    =     5.0; {s,  cutoff to seperation time}
  S3_D     =  8.4074; {m,  stage diameter}
  S3_au    =      30; {degrees, ullage motor offset angle}
  S3_Tu    =    3.87; {s,  ullage motor burn time}
  S3_Tu1   =    0.18; {s,  ullage motor burn time before Core separation}
  S3_Tu2   =   11.72; {s,  ullage motor separation after Core separation}

  {Stage 3 engine constants}
  S3_Eng_Name = 'J-2X';
  S3_F     = 1281088; {N,   vacuum thrust}
  S3_V     =  4275.7; {m/s, vacuum exhaust speed}
  S3_De    =   3.048; {m,   nozzle exit diameter}
  S3_Me    =    2472; {kg, engine mass}

  {Spacecraft constants}
  LAS_M    =    7394; {kg, Launch Abort System mass}
  SAJ_M    =     920; {kg, Jettisoned adaptor mass}

  {Launch constants}
  inc      =   28.45; {deg, Kennedy Space Center inclination}
  h_turn   =     110; {m,   pitch over altitude}
  angle1   =    -0.3; {deg, pitch over angle rate for stage 1}
  amax1    =   29.42; {m/s^2, maximum acceleration strain}
  hpmin    =  200000; {m,   minimum orbital altitude}

  {Stage 3 Reference values}
  S3_Mi_r  =    7394; {kg, reference interstage mass}
  S3_M_r   =  237501; {kg, reference third stage mass}
  SC_M_r   =   96910; {kg, reference spacecraft mass}
  SP_M_r = S3_M_r+SC_M_r; {reference stage and payload mass}
  fmax_r   = 7989605; {N,  reference SP maximum force}
  S3_Mi_s = S3_Mi_r/fmax_r; {interstage mass scale factor}

  RCS_M_r  =     136; {kg, reference RCS propellant mass}
  RCS_M_s = RCS_M_r/SP_M_r; {RCS mass scale factor}

  SIVB_M   =  166258; {kg, S-IVB mass}
  SIVB_Mup =    53.5; {kg, S-IVB solid motor ullage propellant mass}
  SIVB_Mus =    61.2; {kg, S-IVB solid motor ullage dry mass}
  SIVB_Fu  =   30159; {N,  S-IVB total ullage motor vacuum thrust for 2 motors}
  SII_M    =  666299; {kg, S-II mass}
  SII_Fu   =  409236; {kg, S-II total ullage motor vacuum thrust for 4 motors}  
  S3_Fu_p = ln(SIVB_Fu/SII_Fu)/ln(SIVB_M/SII_M); {ullage motor thrust power 
                                                 factor}
  S3_Fu_s = SIVB_Fu/exp(S3_Fu_p*ln(SIVB_M)); {ullage motor thrust scale factor}
  S3_Mup_s = SIVB_Mup/SIVB_Fu; {ullage motor propellant mass scale factor}
  S3_Mus_p = 0.848; {ullage motor dry mass power factor}
  S3_Mus_s = SIVB_Mus/exp(S3_Mus_p*ln(SIVB_Mup)); {ullage motor propellant mass 
                                                   scale factor}

  S3_Mp_r =  210966; {kg, reference third stage propellant mass}
  S3_Md_r =   26399; {kg, reference third stage dry mass, includes engines}
  S3_Me_r =    2472; {kg, reference J-2X third stage engine mass}
  S3_N_r  =       2; {kg, reference number of engines}
  S3_Md_p =   0.848; {third stage dry mass power factor}
  S3_Md_s = (S3_Md_r-S3_N_r*S3_Me_r)/exp(S3_Md_p*ln(S3_Mp_r)); {third stage dry 
                                                       mass scale factor}

  S3_Mps  = S3_N*385.5; {kg, third stage startup propellant mass}
  S3_Mpr_r =   3480; {kg, reference third stage reserve propellant mass}
  S3_Mpr_s = S3_Mpr_r/(S3_Mp_r-S3_Mpr_r); {third stage reserve propellant mass
                                           scale factor}